package com.caimei365.order.service;

import com.caimei365.order.model.ResponseJson;
import com.caimei365.order.model.dto.ReceiptDto;
import com.caimei365.order.model.po.ReceiptPo;
import com.caimei365.order.model.vo.*;
import com.github.pagehelper.PageInfo;
import org.springframework.http.HttpHeaders;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/2/11
 */
public interface ReceiptService {
    /**
     * 线下收款用户微信授权
     *
     * @param code          微信授权code
     * @param encryptedData 微信加密数据
     * @param iv            加密算法的初始向量
     * @return receiptUser
     */
    ResponseJson<ReceiptUserVo> receiptAuthorization(String code, String encryptedData, String iv, HttpHeaders headers);

    /**
     * 线下收款用户密码登录
     *
     * @param mobile   手机号
     * @param password 密码
     */
    ResponseJson<ReceiptUserVo> passwordAuthorization(String mobile, String password, String code, String encryptedData, String iv, HttpHeaders headers);

    /**
     * 获取收款类型
     */
    ResponseJson<List<ReceiptTypeVo>> getReceiptType();

    /**
     * 识别收款短信
     *
     * @param smsContent 收款短信
     */
    ResponseJson<ReceiptVo> readSmsMessage(String smsContent, String openid);

    /**
     * 保存收款信息
     */
    ResponseJson<ReceiptPo> saveReceipt(ReceiptDto receiptDto);

    /**
     * 获取收款列表
     *
     * @param receiptType   收款款项类型：1订单款，2非订单款，3返佣款 4订单款或者非订单款（因财务阶段无法区分订单非订单）, 5供应商退款
     * @param receiptStatus 收款状态：1待确认、2已确认(待审核)、3审核通过、4审核未通过、5收款撤销【线上支付成功为审核通过】
     * @param smsContent    收款短信
     * @param startDate     筛选开始时间
     * @param endDate       筛选结束时间
     * @param openid        微信openid
     * @param pageNum       页码
     * @param pageSize      每页数量
     */
    ResponseJson<PageInfo<ReceiptVo>> getReceiptList(String receiptType, String receiptStatus, String smsContent, String startDate, String endDate, String openid, int pageNum, int pageSize);

    /**
     * 获取收款详情
     *
     * @param id     款项Id
     * @param openid 微信openid
     */
    ResponseJson<ReceiptVo> getReceiptDetail(Integer id, String openid);

    /**
     * 获取收款商品订单列表
     *
     * @param id                 收款ID
     * @param organizeId         组织ID
     * @param orderReceiptStatus 订单收款状态：1待收款，2部分收款，3已收款
     * @param userName           客户名称
     * @param openid             微信openid
     * @param pageNum            页码
     * @param pageSize           每页数量
     */
    ResponseJson<PageInfo<OrderVo>> getReceiptOrderList(Integer id, Integer type, Integer organizeId, String orderReceiptStatus, String userName, String openid, int pageNum, int pageSize);

    /**
     * @param id            返佣收款ID
     * @param confirmedType 0待确认，2已确认子订单
     * @param shopName      供应商名称
     * @param userName      客户名称搜索使用
     * @param openid        微信openid
     * @param pageNum       页码
     * @param pageSize      每页数量
     */
    ResponseJson<PageInfo<ShopOrderVo>> getRefundShopOrderList(Integer id, Integer confirmedType, String shopName, String userName, String openid, int pageNum, int pageSize);
}
